#include <iostream>
#include <QtCore>
#include <QtGui>

#include "Player.h"
#include "UI.h"
#include "Engine.h"

int main(int argc, char  * argv[])
{
    Player app(argc, argv);
    app.setApplicationName("NecroPlayer2");

    return app.exec();
}
